@@ -8,10 +8,11 @@ import (
 	"os"
 	"time"
 
+	"github.com/cppforlife/cobrautil"
 	uierrs "github.com/cppforlife/go-cli-ui/errors"
 	"github.com/cppforlife/go-cli-ui/ui"
-	"github.com/k14s/kapp/pkg/kapp/cmd"
-	cmdapp "github.com/k14s/kapp/pkg/kapp/cmd/app"
+	"github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd"
+	cmdapp "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd/app"
 
 	// Import to initialize client auth plugins.
 	_ "k8s.io/client-go/plugin/pkg/client/auth"
@@ -45,6 +46,9 @@ func nonExitingMain() error {
 		return err
 	}
 
-	confUI.PrintLinef("Succeeded")
+	if !cobrautil.IsCobraInternalCommand(os.Args) {
+		confUI.PrintLinef("Succeeded")
+	}
+
 	return nil
 }
