@@ -7,8 +7,8 @@ import (
 	"fmt"
 	"strings"
 
-	ctlconf "github.com/k14s/kapp/pkg/kapp/config"
-	ctlres "github.com/k14s/kapp/pkg/kapp/resources"
+	ctlconf "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/config"
+	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
 )
 
 const (
