@@ -133,6 +133,8 @@ metadata:
 	assert.NoError(t, err)
 	secondDeploy, err := os.CreateTemp(os.TempDir(), "output2")
 	assert.NoError(t, err)
+	thirdDeploy, err := os.CreateTemp(os.TempDir(), "output3")
+	assert.NoError(t, err)
 
 	defer func() {
 		os.Remove(firstDeploy.Name())
@@ -147,6 +149,10 @@ metadata:
 		kapp.RunWithOpts([]string{"deploy", "--app-metadata-file-output", secondDeploy.Name(), "-f", "-", "-a", name}, RunOpts{IntoNs: true, StdinReader: strings.NewReader(yaml2)})
 	})
 
+	logger.Section("deploy with no changes", func() {
+		kapp.RunWithOpts([]string{"deploy", "--app-metadata-file-output", thirdDeploy.Name(), "-f", "-", "-a", name}, RunOpts{IntoNs: true, StdinReader: strings.NewReader(yaml2)})
+	})
+
 	configMapFirstDeploy, err := os.ReadFile(firstDeploy.Name())
 	assert.NoError(t, err)
 
@@ -160,6 +166,13 @@ metadata:
 	secondConfigMap := yamlSubset{}
 	require.NoError(t, yaml.Unmarshal(configMapSecondDeploy, &secondConfigMap))
 	require.Equal(t, yamlSubset{LastChange: lastChange{Namespaces: []string{env.Namespace}}, UsedGKs: []usedGK{{Group: "", Kind: "Secret"}}}, secondConfigMap)
+
+	configMapThirdDeploy, err := os.ReadFile(thirdDeploy.Name())
+	assert.NoError(t, err)
+
+	thirdConfigMap := yamlSubset{}
+	require.NoError(t, yaml.Unmarshal(configMapThirdDeploy, &thirdConfigMap))
+	require.Equal(t, yamlSubset{LastChange: lastChange{Namespaces: []string{env.Namespace}}, UsedGKs: []usedGK{{Group: "", Kind: "Secret"}}}, thirdConfigMap)
 }
 
 type usedGK struct {
