@@ -4,6 +4,7 @@
 package e2e
 
 import (
+	"regexp"
 	"testing"
 
 	"github.com/cppforlife/go-cli-ui/ui"
@@ -24,3 +25,28 @@ func validateChanges(t *testing.T, respTable []ui.JSONUITableResp, expected []ma
 	require.Equalf(t, notesWaitTo, respTable[0].Notes[1], "Expected to see correct summary, but did not: '%s'", output)
 
 }
+
+func replaceAge(result []map[string]string) []map[string]string {
+	for i, row := range result {
+		if len(row["age"]) > 0 {
+			row["age"] = "<replaced>"
+		}
+		result[i] = row
+	}
+	return result
+}
+
+func replaceLastChangeAge(result []map[string]string) []map[string]string {
+	for i, row := range result {
+		if len(row["last_change_age"]) > 0 {
+			row["last_change_age"] = "<replaced>"
+		}
+		result[i] = row
+	}
+	return result
+}
+
+func replaceAnnsLabels(in string) string {
+	replaceAnns := regexp.MustCompile("kapp\\.k14s\\.io\\/(app|association): .+")
+	return replaceAnns.ReplaceAllString(in, "-replaced-")
+}
